==> kyamo_0.13.99+0.2a.orig.tar.gz: kyamo-0.2a/src/choicebox.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _CHOICEBOX_H_
#define _CHOICEBOX_H_

#include <qdialog.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qlistview.h>
#include <qsize.h>
#include <qstring.h>
#include <qstringlist.h>
#include <klocale.h>

class choicebox : public QDialog
{
Q_OBJECT
public:
choicebox(QStringList *);
~choicebox()
{};
QString selected;
private:
QBoxLayout *choiceboxlayout;
QListView *choicelistbox;
QPushButton *okbutton;
private slots:
void selectcd();
};

#endif //_CHOICEBOX_H_

==> kyamo-0.40a4-2.tar.gz: kyamo-0.40a4-2/src/choicebox.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Roland Weigert   *
 *   roweigert@t-online.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _CHOICEBOX_H_
#define _CHOICEBOX_H_

#include <qdialog.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qlistview.h>
#include <qimage.h>
#include <qiconset.h>
#include <qstring.h>
#include <qsize.h>
#include <qgroupbox.h>
#include <qstringlist.h>

#include <kiconloader.h>
#include <klocale.h>

#include "tagguesser.h"

class guessfilter;

class choicebox : public QDialog
{
    Q_OBJECT
public:
    choicebox(QStringList *,QString,QString);
    choicebox(QPtrList<guessfilter> *,QString);
    ~choicebox();
    bool abort;
    QString selected;
    QString selectedfilter;
private:
    QBoxLayout *choiceboxlayout;
    QGroupBox *infobox;
    QGroupBox *buttonbox;
    QLabel *questionicon;
    QLabel *infotext;
    QListView *choicelistbox;
    QPushButton *okbutton;
    QPushButton *chancelbutton;
    QImage filterpic;
    QImage serverpic;
    QImage newfilterpic;
    QImage okpic;
    QImage chancelpic;
    QImage questionpic;
private slots:
    void selectcd();
    void checkokenabled();
    void chanceldialog();
    void selectfilter();
    void closeEvent(QCloseEvent*);
};

#endif //_CHOICEBOX_H_
